@@ -2,7 +2,7 @@ package Net::AMQP::RabbitMQ;
 use strict;
 use warnings;
 
-our $VERSION = '0.007001';
+our $VERSION = '0.008000';
 
 use XSLoader;
 XSLoader::load "Net::AMQP::RabbitMQ", $VERSION;
@@ -243,6 +243,7 @@ containing the following information:
        routing_key => 'nr_test_q',        # route the message took
        exchange => 'nr_test_x',           # exchange used
        delivery_tag => 1,                 # (used for acks)
+       redelivered => $boolean            # if message is redelivered
        consumer_tag => 'c_tag',           # tag from consume()
        props => $props,                   # hashref sent in
      }
@@ -264,6 +265,17 @@ C<$props> is the hash sent by publish()  respecting the following keys:
        timestamp => $integer,
      }
 
+=head2 cancel($channel, $consumer_tag)
+
+C<$channel> is a channel that has been opened with C<channel_open>.
+
+C<$consumer_tag> is a tag previously passed to C<consume()> or one that was
+generated automatically as a result of calling C<consume()> without an
+explicit tag.
+
+This method returns true or false indicating whether we got the expected
+"cancel-ok" response from the server.
+
 =head2 get($channel, $queuename, $options)
 
 This command runs an amqp_basic_get which returns undef immediately
